\\ Copyright 2022, 2023 Kevin Ryde

\\ This file is part of pari-primecount.

\\ pari-primecount is free software; you can redistribute it and/or modify it
\\ under the terms of the GNU General Public License as published by the Free
\\ Software Foundation; either version 3, or (at your option) any later
\\ version.
\\
\\ pari-primecount is distributed in the hope that it will be useful, but
\\ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
\\ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
\\ for more details.
\\
\\ You should have received a copy of the GNU General Public License along
\\ with pari-primecount.  If not, see <http://www.gnu.org/licenses/>.


\\ This form using the program only.
\\ Think adapting automatically library vs program is better.


\\ Usage: read("primecount_program.gp");
\\        prime = primecount_program_prime(10^10);
\\        num = primecount_program_primepi(10^9);
\\
\\ This is a simple interface to the "primecount" program which
\\ is the command line form of the primecount library by
\\ Kim Walisch.  It calculates large prime() and primepi().
\\
\\
\\ Changes
\\ -------
\\
\\ Version 1 - the first version.

primecount_program_version = 1;

primecount_program_INTERNAL_program = "primecount";

{
\\ if not already set by the user
if(primecount_program_verbose=='primecount_program_verbose,
primecount_program_verbose = 0
);
}

\\-----------------------------------------------------------------------------

\\ program run like
\\     primecount -n 12345
\\
primecount_program_INTERNAL_run(operation,n) =
{
  \\ --status goes to stdout too, would need to pick out result
  \\ if(primecount_program_verbose,
  \\    " --status", ""),

  my(str=Str(primecount_program_INTERNAL_program,
             " ",operation," ",n));
  if(primecount_program_verbose, print(str));
  my(value=extern(str));
  type(value) == "t_INT" || error("oops, result not a number");
  value;
}


primecount_program_prime(n) = primecount_program_INTERNAL_run("-n",n);
{
addhelp(primecount_program_prime,
"prime = primecount_program_prime(n)
Return the n'th prime.
Like prime(n) but running the \"primecount\" program.

At the time of writing on a 32-bit system, primecount is restricted to just
over n = 2*10^17 and a GP error() and some primecount error message result
on attempting bigger.");
}

primecount_program_primepi(n) = primecount_program_INTERNAL_run("",n);
{
addhelp(primecount_program_primepi,
"num = primecount_program_primepi(n)
Return the number of primes <= n.
Like primepi(n) but running the \"primecount\" program.");

\\-----------------------------------------------------------------------------
